![UVG](https://res.cloudinary.com/webuvg/image/upload/f_auto/v1551291412/WEB/institucional/logouvg.png) <br>
Facultad de Ingeniería <br>
Departamento de Ciencias de la Computación <br>
Inteligencia Artificial <br>

## Descripcion

<br>

**Librería simple que permite la creación de redes bayesianas.** <br>
<br>